package com.jobs.pojo;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;
import org.springframework.data.mongodb.core.geo.GeoJsonPoint;
import org.springframework.data.mongodb.core.index.GeoSpatialIndexType;
import org.springframework.data.mongodb.core.index.GeoSpatialIndexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.data.mongodb.core.mapping.Field;
import org.springframework.data.mongodb.core.mapping.MongoId;

//使用该注解，类中可以省略 get set 等方法的编写
@Data
//使用该注解，标明要操作的 mongodb 的文档（相当于数据库的表）
@Document("tb_company")
//使用该注解，可以使用对象实例化赋值采用链式编写
@Accessors(chain = true)
public class Company {

    //使用该注解，标明 mongodb 文档的主键 id
    @MongoId
    private String id;

    //如果 mongodb 文档的字段名与该实体类的字段名不一致
    //使用该注解，标明 mongodb 文档中实际的字段名
    @Field("cname")
    private String name; //企业名称

    //该索引表示空间索引（必须要使用该索引，否则空间查询可能会报错）
    //GEO_2DSPHERE 表示类似球面数据存储索引
    //数组中，0 索引存储经度，1 索引存储纬度
    @GeoSpatialIndexed(type = GeoSpatialIndexType.GEO_2DSPHERE)
    private double[] location;
}
